FidoRegResponse class

Available extensions

Constructors

FidoRegResponse({required bool success, String? message, String? data, String? errorCode})

Properties

data String?
getter/setter pair
errorCode String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>

Available on FidoRegResponse, provided by the FidoRegResponseJson extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) FidoRegResponse